<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet
  version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:saxon="http://saxon.sf.net/"
  xmlns:my="myFunctions" 
>
<!-- 
<purpose> generate html view (probably various formats of a MDRepository response.</purpose>
<params>
<param name=""></param>
</params>
<history>	
	<change on="2010-03-26" type="created" by="vr">based on cmdi/scripts/cmdinst2view.xsl</change>	
</history>
-->

<xsl:output method="html" />

<xsl:include href="cmd_commons.xsl"/>

<xsl:param name="startRecord">1</xsl:param>
<xsl:param name="maximumRecords">50</xsl:param>

<!-- <xsl:param name="format" select="'table'" /> table|list|detail -->
<xsl:param name="cols" >Id,Title,Location
<!-- 
<col label="id">Id</col>
<col label="id">idno</col>
<col label="name">Name</col>
<col label="title">Title</col>
<col label="title">title</col>
<col label="loc" >Location</col>
<col label="loc" >pubPlace</col>
<col label="lang" >language</col>

 -->
</xsl:param>

<xsl:param name="mode" select="'html'" />
<xsl:param name="title" >
	<xsl:text>MDRecordSet </xsl:text>
</xsl:param>

<xsl:variable name="columns" >
<xsl:message>COLUMNS: <xsl:value-of select="$cols" /><xsl:value-of select="string-length($cols)" /></xsl:message>
	<xsl:variable name="colarray" select="tokenize($cols,',')"/>
	<xsl:for-each select="$colarray" >
		<col key="{.}" label="{replace(.,'^.*\.([^.]+)$','$1')}" xpath="{replace(.,'\.','/')}" />
		<!-- if (contains(.,'.')) then reverse(.) else . -->
	</xsl:for-each>
	<xsl:if test="count($colarray)=0" >	
		<xsl:copy-of select="$autocolumns"></xsl:copy-of>
		<xsl:message>AUTOCOLUMNS: <xsl:copy-of select="$autocolumns" /><xsl:value-of select="count($autocolumns)" /></xsl:message>
	</xsl:if>
	
</xsl:variable>

<xsl:variable name="autocolumns" >
	<xsl:variable name="precompute">
		<xsl:for-each-group select="//Components//*[not(*)][exists(text())]" group-by="name()" >			
			<xsl:sort select="sum(current-group()/string-length(string-join(text(),';')))" order="descending" />
			<!-- <xsl:message>precomputing: <xsl:value-of select="name()" />
				count: <xsl:value-of select="count(current-group())" /> sum:<xsl:value-of select="sum(current-group()/string-length(string-join(text(),';')))" /></xsl:message> -->
			<col key="{name()}" label="{name()}" xpath="{name()}" />
		</xsl:for-each-group>
	</xsl:variable>
	 <!-- <xsl:message>precompute: <xsl:copy-of select="$precompute" /><xsl:value-of select="count($precompute)" /></xsl:message>-->
	<xsl:copy-of select="$precompute/*[position() &lt; $autocolumns_limit]"></xsl:copy-of> 
</xsl:variable>

<xsl:template name="continue-root" >

<xsl:for-each select="searchRetrieveResponse" >
	<xsl:call-template name="header" />
	<xsl:choose>
				<xsl:when test="contains($format,'htmltable')">
					<xsl:apply-templates select="records" mode="table" />
				</xsl:when>				
				<xsl:when test="contains($format,'htmllist')">
					<xsl:apply-templates select="records" mode="list" />
				</xsl:when>				
				<xsl:when test="contains($format, 'htmldetail')">
					<xsl:apply-templates select="records" mode="detail" />
				</xsl:when>
				<xsl:when test="contains($format, 'htmlpage')">
					<xsl:apply-templates select="records" mode="detail" />
				</xsl:when>				
				<xsl:otherwise>mdset2view: unrecognized format: <xsl:value-of select="$format" /></xsl:otherwise>
	</xsl:choose>
</xsl:for-each>	
	
</xsl:template>	
	
	
<xsl:template match="*" >
	<!-- <xsl:param name="lv" select="1" />-->
	<!--<xsl:variable name="lv" select="count(ancestor::d)" /> -->
	<xsl:if test="string-length(.//text()) &gt; 1" >
		<xsl:variable name="has_text" >
			<xsl:choose>
				<xsl:when test="normalize-space(text())='Unspecified'">unspecified</xsl:when>
				<xsl:when test="not(normalize-space(text())='')">text</xsl:when>				
				<xsl:otherwise>empty</xsl:otherwise>
			</xsl:choose>
			
		</xsl:variable>
		<div class="elem {$has_text}" ><span class="elem_name"><xsl:value-of select="name()" />:</span>
		<span class="elem_value"><xsl:value-of select="text()" /></span>
			<xsl:apply-templates select="*" />					
		</div>	
	</xsl:if>
</xsl:template>	
	
	<!--
sample header:	
<numberOfRecords>524</numberOfRecords>
    <echoedSearchRetrieveRequest>//Title[contains(.,'an')] /db/cmdi-mirror/silang_data 1 50</echoedSearchRetrieveRequest>
    <diagnostics>50</diagnostics>
    -->
<xsl:template name="header">
	<div class="result-header" >
	<xsl:attribute name="max_value"><xsl:value-of select="numberOfRecords" /></xsl:attribute>
	<xsl:variable name="cnt_hits" select="number(diagnostics)" />	
	<span class="label" >hits: </span><span class="value hilight"><xsl:value-of select="numberOfRecords" /></span>;
	<span class="label" >from:</span><span><input type="text" class="value start_record paging-input"><xsl:attribute name="value">
    <xsl:value-of select="$startRecord"/>
  </xsl:attribute>
	</input></span>
	<span class="label" >max:</span><span><input type="text" class="value maximum_records paging-input" ><xsl:attribute name="value">
    <xsl:value-of select="if(number($cnt_hits) &lt; number($maximumRecords)) then $cnt_hits else $maximumRecords"/>    
  </xsl:attribute></input></span>
  <span class="cmd cmd_reload" />
<!--	<button class="reload">reload</button>-->
	<span class="cmd cmd_prev">	
	<xsl:choose>
		<xsl:when test="$startRecord = '1'">
			<xsl:attribute name="disabled">disabled</xsl:attribute>
		</xsl:when>
		</xsl:choose>
	</span>
	<span class="cmd cmd_next">
	<xsl:choose>
		<xsl:when test="$maximumRecords &gt; numberOfRecords or $maximumRecords = numberOfRecords">
			<xsl:attribute name="disabled">disabled</xsl:attribute>
		</xsl:when>
		</xsl:choose>
	</span>
    </div>
        <div class="note" ><span class="label" >echo: </span><span class="value"><xsl:value-of select="echoedSearchRetrieveRequest" /></span>;</div>
</xsl:template>	

<xsl:template match="records" mode="table">
    
	<table class="show">		
		<thead><tr><th>pos</th>
		<!-- 
			 <xsl:for-each select="$cols/col" >
			<xsl:for-each select="distinct-values($cols/col/@label)" >
					<th><xsl:value-of select="." /></th>
			</xsl:for-each>		
		 -->
			<xsl:for-each select="$columns/*">
  				<th title="{@key}" ><xsl:value-of select="@label"/></th>
  			</xsl:for-each>
  			<th><span class="edit-columns"> edit...</span> </th>
		</tr></thead>
		<tbody>		
			<xsl:apply-templates select="CMD" mode="table" />			
		</tbody>
	</table>

</xsl:template>

<xsl:template match="CMD" mode="table">
		<tr>
		<td>
			<xsl:choose>
				<xsl:when test="exists(.//MdSelfLink)" >
				<a class="internal" href="{concat('record/htmldetail/', my:encodePID(.//MdSelfLink))}" >
						<xsl:value-of select="position()" />
				</a>
				<span class="cmd cmd_detail" ></span>				
				<span class="cmd cmd_save" ></span>						
				</xsl:when>
				<xsl:otherwise><xsl:value-of select="position()" /></xsl:otherwise>
			</xsl:choose>
		</td>
		<xsl:variable name="curr_cmd" select="." />
		<!-- <xsl:for-each select="$cols/col" >
					<td ><xsl:value-of select="$curr_cmd//*[name()=current()]" /></td>
				<xsl:for-each select="distinct-values($cols/col/@label)" >
					<td >
					 <xsl:value-of select="$curr_cmd//*[name()=current()]" />  
						 <xsl:for-each select="$cols/col[@label=current()]" > 
						 <xsl:variable name="curr_col_xpath" select="text()" />	
							
						  	<xsl:message><xsl:value-of select="$curr_col_xpath" /></xsl:message>
						 
							<xsl:for-each select="$curr_cmd" >
									<xsl:value-of select="saxon:evaluate(concat('.//', $curr_col_xpath))" />
							</xsl:for-each>
						</xsl:for-each>
					</td>
				</xsl:for-each>
		  -->

			<xsl:for-each select="$columns/*">
  			<!-- <td ><xsl:value-of select="$curr_cmd//*[name()=current()]" /></td> -->
 				 <xsl:variable name="curr_col_xpath" select="@xpath" />
  			<td>  			
  				<xsl:for-each select="$curr_cmd">
  					<xsl:call-template name="format-field" >
  						<xsl:with-param name="elems" select="saxon:evaluate(concat('.//', $curr_col_xpath))" />
  					</xsl:call-template> 					
  				
  				</xsl:for-each>
  			</td>
  			</xsl:for-each>
		</tr>									
</xsl:template>


</xsl:stylesheet>